@@ -60,8 +60,7 @@ class PageFactory(object):
             element = self.get_web_element(*locator)
             element._locator = locator
             return element
-        else:
-            return super().__getattr__(loc)
+        return super().__getattr__(loc)
 
     def get_web_element(self, *loc):
         element = self.driver.find_element(*loc)
@@ -144,6 +143,7 @@ class PageFactory(object):
         :return: True / False
         """
         select = Select(self)
+        list_item = []
         for item in select.options:
             if text == item.text:
                 return True
@@ -237,6 +237,14 @@ class PageFactory(object):
         """
         return self.get_attribute(attributeName)
 
+    def setAttribute(self, attributeName, value):
+        """
+        set webElement attribute
+        :param: name of Attribute, value to be set
+        :return: none
+        """
+        return self.parent.execute_script("arguments[0].setAttribute(" + attributeName + "," + value + ")", self)
+
     def w3c(self):
         return self.w3c
 
@@ -250,28 +258,6 @@ class PageFactory(object):
             EC.element_to_be_clickable(self._locator)
         )
 
-    def text_to_be_present_in_element(self,text,timeout=None):
-        """
-        Wait till the text to be present in element
-        :param: text to be verified with element
-        """
-        if timeout is None:
-            timeout = PageFactory().timeout
-        return WebDriverWait(self.parent, timeout).until(
-            EC.text_to_be_present_in_element(self._locator,text_=text)
-        )
-
-    def element_located_selection_state_to_be(self,state,timeout=None):
-        """
-        Wait till element to be located and check if the selection state specified is in that state
-        :param: state to verified with an element in boolean
-        """
-        if timeout is None:
-            timeout = PageFactory().timeout
-        return WebDriverWait(self.parent, timeout).until(
-            EC.element_located_selection_state_to_be(self._locator,is_selected=state)
-        )
-
     def invisibility_of_element_located(self, timeout=None):
         """
         Wait till the element to be invisible
@@ -315,6 +301,7 @@ WebElement.w3c = PageFactory.w3c
 WebElement.is_Checked = PageFactory.is_Checked
 WebElement.is_Enabled = PageFactory.is_Enabled
 WebElement.getAttribute = PageFactory.getAttribute
+WebElement.setAttribute = PageFactory.setAttribute
 WebElement.select_element_by_text = PageFactory.select_element_by_text
 WebElement.select_element_by_index = PageFactory.select_element_by_index
 WebElement.select_element_by_value = PageFactory.select_element_by_value
@@ -322,6 +309,4 @@ WebElement.get_list_item_count = PageFactory.get_list_item_count
 WebElement.get_all_list_item = PageFactory.get_all_list_item
 WebElement.get_list_selected_item = PageFactory.get_list_selected_item
 WebElement.execute_script = PageFactory.execute_script
-WebElement.text_to_be_present_in_element = PageFactory.text_to_be_present_in_element
-WebElement.element_located_selection_state_to_be = PageFactory.element_located_selection_state_to_be
 WebElement.verify_list_item = PageFactory.verify_list_item
